@@ -108,8 +108,8 @@ pixels = neopixel.NeoPixel(
     pixel_pin, num_pixels, brightness=0.0, auto_write=False, pixel_order=neopixel.GRB
 )
 
-def to_rgb_tuple(s):
-    return int(s[1:3], 16), int(s[3:5], 16), int(s[5:], 16)
+def to_grb_tuple(s):
+    return int(s[3:5], 16), int(s[:3], 16), int(s[5:], 16)
 
 
 config_queue = queue.Queue()
@@ -125,7 +125,7 @@ def init_config(config: LedRegulatorSequence):
         pixels.show()
         time.sleep(0.5)
 
-    pixels.fill(to_rgb_tuple(config.color))
+    pixels.fill(to_grb_tuple(config.color))
     pixels.brightness = config.initial_brightness
     pixels.show()
 
@@ -142,13 +142,14 @@ def worker():
         except queue.Empty:
             logger.warning(f"No new task found. Continuing with\n{current_config}")
 
-        pixels.brightness = config.initial_brightness
+        pixels.brightness = current_config.initial_brightness
         pixels.show()
         for target, seconds in current_config.sequence:
             delta = (target - pixels.brightness) / (seconds * SMOOTHNESS)
-            logger.warning(f"Computed delta {delta} from {target} and {time}\n")
             op_func = operator.gt if target < pixels.brightness else operator.lt
-            while op_func(pixels.brightness, target):
+            logger.warning(f"Computed delta {delta} and op_func {op_func} from {target} and {seconds}\n")
+            while op_func(pixels.brightness, target or 0.01):
+                logger.warning(f"running cur brightness {pixels.brightness}")
                 pixels.brightness += delta
                 pixels.show()
                 time.sleep(sleep_time)
